@@ -79,7 +79,10 @@ class Event(models.Model):
     tags = TaggableManager(blank=True)
 
     def __unicode__(self):
-        return self.name
+        date_format = '%Y-%m-%d %I:%M %p'
+        if self.all_day_event:
+            date_format = '%Y-%m-%d'
+        return '%(n)s (%(d)s)' % {'n': self.name, 'd': self.start_date_time..strftime(date_format), }
 
     def save(self):
         if self.all_day_event:
@@ -98,9 +101,6 @@ class Event(models.Model):
     active.boolean = True
     active.short_description = _('Active')
 
-    def fake_slug(self):
-        pass
-
     def calendar_color(self):
         return '<span style="display: inline-block; width: 13px; height: 13px; background-color: %(c)s; border: 1px solid #000; margin-right: 7px;"></span> %(cn)s' % {'c': self.calendar.color.color, 'cn': self.calendar.name, }
     calendar_color.allow_tags = True
@@ -109,7 +109,6 @@ class Event(models.Model):
     class Meta:
         verbose_name = _('Event')
         verbose_name_plural = _('Events')
-        #unique_together = ('start_date_time', 'slug', )
 
 
 class EventClassification(models.Model):
